@@ -6,11 +6,10 @@
 ### see http://www.apache.org/licenses/LICENSE-2.0         ###
 ##############################################################
 
-from .Radiko import Radiko
-from .Exception import RadikoException
+from .Radiko import *
 
 __copyright__    = "Copyright © 2020 kokarare1212 All rights reserved."
-__version__      = "1.1.3"
+__version__      = "1.2.0"
 __license__      = "Apache License 2.0"
 __author__       = "kokarare1212"
 __author_email__ = "kokarare1212@gmail.com"
